bincap-class: Class "bincap" in Package HandTill2001
Description
S4 class for a two class response and corresponding
(predicted) probabilities.Objects from the Class
Objects can be created by calls of the form
new("bincap", ...). They are used to store a two
class response (one of the two levels of which is
supposed to be true), the information which of the
two levels of the two class response is thought of
as 'true'/'positive'/'present' (the other one would then
be thought of as 'false'/'negative'/'absence') and the
predicted probabilities that response is
true.